## Typing stubs for psutil

This is a [type stub package](https://typing.python.org/en/latest/tutorials/external_libraries.html)
for the [`psutil`](https://github.com/giampaolo/psutil) package. It can be used by type checkers
to check code that uses `psutil`. This version of
`types-psutil` aims to provide accurate annotations for
`psutil==7.1.3`.

This package is part of the [typeshed project](https://github.com/python/typeshed).
All fixes for types and metadata should be contributed there.
See [the README](https://github.com/python/typeshed/blob/main/README.md)
for more details. The source for this package can be found in the
[`stubs/psutil`](https://github.com/python/typeshed/tree/main/stubs/psutil)
directory.

This package was tested with the following type checkers:
* [mypy](https://github.com/python/mypy/) 1.18.2
* [pyright](https://github.com/microsoft/pyright) 1.1.407

It was generated from typeshed commit
[`1218f18d895b059664439e3d6834de09ff7b07e2`](https://github.com/python/typeshed/commit/1218f18d895b059664439e3d6834de09ff7b07e2).